source("exopep.R")

# creating the cleavage graph
model <- make.model(c("ABBBAABABABBAAABBAAABABBA", "BABBBABBBA"), min.len=2)

# generating artificial observations
cutting.weights <- c(1, 6, 3, 2) / 12
in.weights <- c(5, 3) / 8
poisson.params <- find.poisson.params(model, cutting.weights, in.weights)$poisson.params # the mu parameters from the paper
data <- make.data(1e6 * poisson.params, sd=0.2, correct.reading.pr=0.9)
x <- data$data
x[sample(length(x), 0.5 * length(x))] <- NA # 50% missing data

# estimating
background <- density(log(data$data), na.rm=TRUE)
background <- approxfun(background$x, background$y, yleft=0, yright=0)
res <- estimate.mh(x, model, 20000, correct.reading.prior=0.7, error.sd.prior=0.2, background=background, verbose=TRUE)

matplot(res$times, res$cutting.weights, type="l", xlab="time", ylab="intensity")
matplot(res$times, res$in.weights, type="l", xlab="time", ylab="intensity")
