#include <R.h>

void top_sort(const int *graph, const int *graph_size,
	      int *parents_num,
	      int *queue, int *queue_size) {
  for(int k = 0; k < *queue_size; ++k) {
    int v = queue[k] - 1;
    int left = graph[v];
    int right = graph[v + *graph_size];
    if(NA_INTEGER == left || NA_INTEGER == right)
      continue;
    if(--parents_num[left-1] == 0)
      queue[(*queue_size)++] = left;
    if(--parents_num[right-1] == 0)
      queue[(*queue_size)++] = right;
  }
}

void find_poisson_params(const int *graph, const int *graph_size,
			 const int *queue,
			 const double *cutting_weights,
			 double *poisson_params,
			 double *flow) {
  for(int k = 0; k < *graph_size; ++k) {
    int v = queue[k] - 1;
    int left = graph[v];
    int right = graph[v + *graph_size];
    double left_intens = cutting_weights[graph[v + 2 * *graph_size] - 1];
    double right_intens = cutting_weights[graph[v + 3 * *graph_size] - 1];
    poisson_params[v] = flow[v] / (left_intens + right_intens);
    if(NA_INTEGER == left || NA_INTEGER == right)
      continue;
    flow[left-1] += left_intens * poisson_params[v];
    flow[right-1] += right_intens * poisson_params[v];
  }
}
